"""
true

Does nothing except return a status code of 0.
"""

def main(*args):
    return 0
